# Copyright 2021 Marcel Konstapel
# https://www.meezenest.nl/mees
#
# This file is part of SolarGeneratorDatalogger.
# A set of programs and scripts to log all the available data from a self build solar generator.
# It runs on a Raspberry Pi Zero 1 W with Raspbian
#
# It logs data from a EPEVER Soalrge Charge Controller (via Bluetooth) and an EPEVER solar charger (via RS485-USB).
# The data is analyzed and stored in a file. The data is also available via a web browser over Wifi
# (Raspberry Pi acts as access point).
# Future plan is to implement LoRa so the data can be accessed remotely.
#
# This program reads a JSON file and returns the value of a field
#
# Usage of program:
#
#  -i, --input_file : the JSON file
#  -f, --field      : the value from this field is returned
#
# V0.1 2021-11-12
#   - First working program
#
#    SolarGeneratorDatalogger is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    SolarGeneratorDatalogger is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with SolarGeneratorDatalogger.  If not, see <https://www.gnu.org/licenses/>.
#
import json
import sys
import time
import getopt

from json.decoder import JSONDecodeError
from datetime import datetime

input_file =""
field =""

argv = sys.argv[1:]
try:
    options, args = getopt.getopt(argv, "i:f:",
                               ["input_file =",
                                "field ="])
except:
    print("This program reads a JSON file and returns the value of a field")
    print("")
    print("  -i, --input_file : the JSON file")
    print("  -f, --field      : the value from this field is returned")
    sys.exit()
 
for name, value in options:
    if name in ['-i', '--input_file']:
        input_file = value
    elif name in ['-f', '--field']:
        field = value
        
if not input_file:
    print("No input file given.")
    sys.exit();

if not field:
    print("No field given.")
    sys.exit();
    
# read configuration file
try:
    with open(input_file, 'r') as myfile:
        data=myfile.read()
except FileNotFoundError:
    print("Input file <"+ input_file +"> not found.")
    sys.exit();

# parse configuration file
try:
    obj = json.loads(data)
    tmp = obj[field]
except JSONDecodeError as e:
    print("Error decoding configuration file. Not JSON format?")
    sys.exit()
except TypeError as e:
    print("Error decoding configuration file: JSON objects not str, bytes or bytearray.")
    sys.exit()
except KeyError:
    print("Error reading configuration file: given field not found.")
    sys.exit()

# show values from input file
print(str(obj[field]))
